@@ -1,5 +1,5 @@
 /*
- * $Id: abook_rl.c,v 1.15 2005/08/08 05:13:51 jheinonen Exp $
+ * $Id: abook_rl.c,v 1.16 2005/09/23 15:42:11 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -166,7 +166,7 @@ abook_rl_init(bool use_completion)
 }
 
 char *
-abook_readline(WINDOW *w, int y, int x, char *s, int limit, bool use_completion)
+abook_readline(WINDOW *w, int y, int x, char *s, bool use_completion)
 {
 	char *ret;
 
