@@ -1,6 +1,6 @@
 
 /*
- * $Id: filter.c,v 1.48.2.1 2005/10/26 19:45:23 jheinonen Exp $
+ * $Id: filter.c,v 1.48.2.1.2.2 2006/04/10 16:02:10 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -908,7 +908,7 @@ pine_fixbuf(char *buf)
 {
 	int i,j;
 
-	for(i=0,j=0; j < (int)strlen(buf); i++, j++)
+	for(i = 0,j = 0; j < (int)strlen(buf); i++, j++)
 		buf[i] = buf[j] == '\n' ? buf[++j] : buf[j];
 }
 
@@ -921,18 +921,17 @@ pine_convert_emails(char *s)
 	if(s == NULL || *s != '(')
 		return;
 
-	for(i=0; s[i]; i++ )
-		s[i] = s[i+1];
+	for(i = 0; s[i]; i++)
+		s[i] = s[i + 1];
 
 	if( ( tmp = strchr(s,')')) )
-		*tmp=0;
+		*tmp = '\0';
 
 	for(i = 1; ( tmp = strchr(s, ',') ) != NULL ; i++, s = tmp + 1)
 		if(i > MAX_EMAILS - 1) {
-			*tmp = 0;
+			*tmp = '\0';
 			break;
 		}
-
 }
 
 static void
@@ -943,11 +942,11 @@ pine_parse_buf(char *buf)
 	char *end;
 	char tmp[PINE_BUF_SIZE];
 	int i, len, last;
-	int pine_conv_table[]= {NICK, NAME, EMAIL, -1, NOTES};
+	int pine_conv_table[] = {NICK, NAME, EMAIL, -1, NOTES};
 
 	memset(&item, 0, sizeof(item));
 
-	for(i=0, last=0; !last ; i++) {
+	for(i = 0, last=0; !last ; i++) {
 		if( !(end = strchr(start, '\t')) )
 			last=1;
 
@@ -1510,7 +1509,7 @@ gcrd_export_database(FILE *out, struct db_enumerator e)
 	char *name;
 
 	db_enumerate_items(e) {
-		fprintf(out, "BEGIN:VCARD\nFN:%s\n",
+		fprintf(out, "BEGIN:VCARD\r\nFN:%s\r\n",
 				safe_str(database[e.item][NAME]));
 
 		name = get_surname(database[e.item][NAME]);
@@ -1518,7 +1517,7 @@ gcrd_export_database(FILE *out, struct db_enumerator e)
 	                if(database[e.item][NAME][j] == ' ')
 	                        break;
 	        }
-		fprintf(out, "N:%s;%.*s\n",
+		fprintf(out, "N:%s;%.*s\r\n",
 			safe_str(name),
 			j,
 			safe_str(database[e.item][NAME])
@@ -1527,7 +1526,7 @@ gcrd_export_database(FILE *out, struct db_enumerator e)
 		free(name);
 
 		if ( database[e.item][ADDRESS] )
-			fprintf(out, "ADR:;;%s;%s;%s;%s;%s;%s\n",
+			fprintf(out, "ADR:;;%s;%s;%s;%s;%s;%s\r\n",
 				safe_str(database[e.item][ADDRESS]),
 				safe_str(database[e.item][ADDRESS2]),
 				safe_str(database[e.item][CITY]),
@@ -1537,29 +1536,32 @@ gcrd_export_database(FILE *out, struct db_enumerator e)
 				);
 
 		if (database[e.item][PHONE])
-			fprintf(out, "TEL;HOME:%s\n", database[e.item][PHONE]);
+			fprintf(out, "TEL;HOME:%s\r\n",
+				database[e.item][PHONE]);
 		if (database[e.item][WORKPHONE])
-			fprintf(out, "TEL;WORK:%s\n", database[e.item][WORKPHONE]);
+			fprintf(out, "TEL;WORK:%s\r\n",
+				database[e.item][WORKPHONE]);
+
 		if (database[e.item][FAX])
-			fprintf(out, "TEL;FAX:%s\n", database[e.item][FAX]);
+			fprintf(out, "TEL;FAX:%s\r\n", database[e.item][FAX]);
 		if (database[e.item][MOBILEPHONE])
-			fprintf(out, "TEL;CELL:%s\n", database[e.item][MOBILEPHONE]);
+			fprintf(out, "TEL;CELL:%s\r\n", database[e.item][MOBILEPHONE]);
 
 		if ( database[e.item][EMAIL] ) {
 			split_emailstr(e.item, emails);
 			for(j=0; j < MAX_EMAILS ; j++) {
 				if ( *emails[j] )
-					fprintf(out, "EMAIL;INTERNET:%s\n",
+					fprintf(out, "EMAIL;INTERNET:%s\r\n",
 						emails[j]);
 			}
 		}
 
 		if ( database[e.item][NOTES] )
-			fprintf(out, "NOTE:%s\n", database[e.item][NOTES]);
+			fprintf(out, "NOTE:%s\r\n", database[e.item][NOTES]);
 		if (database[e.item][URL])
-			fprintf(out, "URL:%s\n",  database[e.item][URL]);
+			fprintf(out, "URL:%s\r\n",  database[e.item][URL]);
 
-		fprintf(out, "END:VCARD\n\n");
+		fprintf(out, "END:VCARD\r\n\r\n");
 
 	}
 
