@@ -1,6 +1,6 @@
 
 /*
- * $Id: misc.c,v 1.19 2005/08/11 07:32:35 jheinonen Exp $
+ * $Id: misc.c,v 1.21 2005/10/05 11:03:36 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -18,9 +18,7 @@
 #ifdef HAVE_CONFIG_H
 #	include "config.h"
 #endif
-#ifdef HANDLE_MULTIBYTE
-#	include <mbswidth.h>
-#endif
+#include <mbswidth.h>
 #include "misc.h"
 #include "xmalloc.h"
 
@@ -82,7 +80,7 @@ strtrim(char *s)
 #endif
 
 char *
-mkstr (const char *format, ... )
+strdup_printf (const char *format, ... )
 {
 	MY_VA_LOCAL_DECL;
 	size_t size = 100;
@@ -274,11 +272,7 @@ int
 strwidth(const char *s)
 {
 	assert(s);
-#ifdef HANDLE_MULTIBYTE
-	return (int)mbswidth(s, 0);
-#else
-	return strlen(s);
-#endif
+	return mbswidth(s, 0);
 }
 
 int
