@@ -1,6 +1,6 @@
 
 /*
- * $Id: options.c,v 1.27 2005/09/21 16:50:31 jheinonen Exp $
+ * $Id: options.c,v 1.27.4.1 2006/04/09 18:57:34 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -226,7 +226,7 @@ find_token_end(buffer *b)
 	}
 }
 
-static char *
+static const char *
 opt_set_set_option(char *var, char *p, struct option *opt)
 {
 	int len;
@@ -265,7 +265,7 @@ opt_set_set_option(char *var, char *p, struct option *opt)
 	return NULL;
 }
 
-static char *
+static const char *
 opt_parse_set(buffer *b)
 {
 	int i;
@@ -288,7 +288,7 @@ opt_parse_set(buffer *b)
 
 #include "database.h" /* needed for change_custom_field_name */
 
-static char *
+static const char *
 opt_parse_customfield(buffer *b)
 {
 	char *p, num[5];
@@ -315,7 +315,7 @@ opt_parse_customfield(buffer *b)
 
 static struct {
 	char *token;
-	char * (*func) (buffer *line);
+	const char * (*func) (buffer *line);
 } opt_parsers[] = {
 	{ "set", opt_parse_set },
 	{ "customfield", opt_parse_customfield },
@@ -326,7 +326,7 @@ static bool
 opt_parse_line(char *line, int n, char *fn)
 {
 	int i;
-	char *err = NULL;
+	const char *err = NULL;
 	char *token;
 	buffer b;
 
