@@ -1,6 +1,6 @@
 
 /*
- * $Id: ui.c,v 1.54 2005/10/05 11:03:36 jheinonen Exp $
+ * $Id: ui.c,v 1.54.4.1 2006/04/09 18:57:34 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -306,7 +306,7 @@ statusline_askchoice(const char *msg, const char *choices, short dflt)
 }
 
 char *
-ui_readline(char *prompt, char *s, size_t limit, bool use_completion)
+ui_readline(const char *prompt, char *s, size_t limit, bool use_completion)
 {
 	int y, x;
 	char *ret;
@@ -327,7 +327,7 @@ ui_readline(char *prompt, char *s, size_t limit, bool use_completion)
 }
 
 int
-statusline_ask_boolean(char *msg, int def)
+statusline_ask_boolean(const char *msg, int def)
 {
 	int ret;
 	char *msg2 = strconcat(msg,  def ? _(" (Y/n)?") : _(" (y/N)?"), NULL);
@@ -363,7 +363,7 @@ refresh_statusline()
 }
 
 char *
-ask_filename(char *prompt)
+ask_filename(const char *prompt)
 {
 	char *buf = NULL;
 
